@@ -13,6 +13,14 @@ my $c =
   Riak::Light->new( host => "localhost", port => 8087,
     timeout_provider => undef );
 
+use Benchmark qw(cmpthese);
+
+cmpthese(
+    1000000,
+    {   foo => sub { print Dumper \@_; }, bar => sub { }
+    }
+);
+
 print Dumper( $c->exists( foo => "foo" ) );
 print Dumper( $c->get_raw( foo => "foo" ) );
 print Dumper( $c->exists( foo => "bar" ) );
